@@ -1,6 +1,6 @@
 /* backend.h -- IMAP server proxy for Cyrus Murder
  *
- * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
+ * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -39,13 +39,15 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: backend.h,v 1.4 2002/07/26 18:30:53 rjs3 Exp $ */
+/* $Id: backend.h,v 1.11 2004/02/04 01:42:38 ken3 Exp $ */
 
 #ifndef _INCLUDED_BACKEND_H
 #define _INCLUDED_BACKEND_H
 
 #include "mboxlist.h"
 #include "prot.h"
+#include "protocol.h"
+#include "tls.h"
 
 /* Functionality to bring up/down connections to backend servers */
 
@@ -53,19 +55,22 @@
 
 struct backend {
     char hostname[MAX_PARTITION_LEN];
-    struct sockaddr_in addr;
+    struct sockaddr_storage addr;
     int sock;
 
-    /* only used by proxyd */
+    /* service-specific context */
+    void *context;
+
+    /* only used by proxyd and nntpd */
     struct prot_waitevent *timeout;
 
     sasl_conn_t *saslconn;
+#ifdef HAVE_SSL
+    SSL *tlsconn;
+    SSL_SESSION *tlssess;
+#endif /* HAVE_SSL */
 
-    enum {
-	ACAP = 0x1, /* not used */
-	IDLE = 0x2,
-	MUPDATE = 0x4
-    } capability;
+    unsigned long capability;
 
     char last_result[LAST_RESULT_LEN];
     struct protstream *in; /* from the be server to me, the proxy */
@@ -74,9 +79,11 @@ struct backend {
 
 /* if cache is NULL, returns a new struct backend, otherwise returns
  * cache on success (and returns NULL on failure, but leaves cache alone) */
-struct backend *findserver(struct backend *cache, const char *server,
-			   const char *userid);
-void downserver(struct backend *s);
+struct backend *backend_connect(struct backend *cache, const char *server,
+				struct protocol_t *prot, const char *userid,
+				const char **auth_status);
+int backend_ping(struct backend *s, struct protocol_t *prot);
+void backend_disconnect(struct backend *s, struct protocol_t *prot);
 
 #define CAPA(s, c) ((s)->capability & (c))
 
