@@ -40,7 +40,7 @@
  */
 
 /*
- * $Id: pop3d.c,v 1.160 2004/06/29 16:22:31 ken3 Exp $
+ * $Id: pop3d.c,v 1.163 2004/09/09 16:21:26 shadow Exp $
  */
 #include <config.h>
 
@@ -233,9 +233,7 @@ static void popd_reset(void)
     }
 #endif
 
-    cyrus_close_sock(0);
-    cyrus_close_sock(1);
-    cyrus_close_sock(2);
+    cyrus_reset_stdio(); 
 
     strcpy(popd_clienthost, "[local]");
     if (popd_logfd != -1) {
@@ -1336,7 +1334,7 @@ void cmd_auth(char *arg)
 int openinbox(void)
 {
     char userid[MAX_MAILBOX_NAME+1], inboxname[MAX_MAILBOX_PATH+1];
-    int type, myrights;
+    int type, myrights = 0;
     char *server = NULL, *acl;
     int r, log_level = LOG_ERR;
     const char *statusline = NULL;
